@@ -61,7 +61,7 @@ The utility pkfilterdem can be used to filter digital elevation models. It is ty
  | minchange | minchange            | short | 0     |Stop iterations when no more pixels are changed than this threshold. | 
  | ot     | otype                | std::string |       |Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image | 
  | of     | oformat              | std::string | GTiff |Output image format (see also gdal_translate).| 
- | ct     | ct                   | std::string |       |color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid). Use none to ommit color table | 
+ | ct     | ct                   | std::string |       |color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid). Use none to omit color table | 
  | nodata | nodata               | short |       |nodata value | 
 
 Usage: pkfilterdem -i input.txt -o output
@@ -85,7 +85,7 @@ int main(int argc,char **argv) {
   Optionpk<short> minChange_opt("minchange", "minchange", "Stop iterations when no more pixels are changed than this threshold.", 0);
   Optionpk<std::string>  otype_opt("ot", "otype", "Data type for output image ({Byte/Int16/UInt16/UInt32/Int32/Float32/Float64/CInt16/CInt32/CFloat32/CFloat64}). Empty string: inherit type from input image","");
   Optionpk<string>  oformat_opt("of", "oformat", "Output image format (see also gdal_translate).","GTiff");
-  Optionpk<string>  colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid). Use none to ommit color table");
+  Optionpk<string>  colorTable_opt("ct", "ct", "color table (file with 5 columns: id R G B ALFA (0: transparent, 255: solid). Use none to omit color table");
   Optionpk<string> option_opt("co", "co", "Creation option for output file. Multiple options can be specified.");
   Optionpk<short> nodata_opt("nodata", "nodata", "nodata value");
   Optionpk<short> verbose_opt("v", "verbose", "verbose mode if > 0", 0,2);
@@ -177,7 +177,7 @@ int main(int argc,char **argv) {
   outputWriter.setProjection(input.getProjection());
   outputWriter.copyGeoTransform(input);
   if(colorTable_opt.size())
-    outputWriter.setColorTable(colorTable_opt[0]);   
+    outputWriter.setColorTable(colorTable_opt[0]);
 
   //set nodata value
   if(nodata_opt.size()){
@@ -347,7 +347,7 @@ int main(int argc,char **argv) {
     outputData=tmpData;
     //todo: interpolate
     //outputData.setMask(tmpData,1,0);
-  }    
+  }
   else if(postFilter_opt[0]=="etew_min"){
     //Elevation Threshold with Expand Window (ETEW) Filter (p.73 from Airborne LIDAR Data Processing and Analysis Tools ALDPAT 1.0)
     //first iteration is performed assuming only minima are selected using options -fir all -comp min
@@ -363,7 +363,7 @@ int main(int argc,char **argv) {
       std::cout << "iteration " << iteration << ": " << nchange << " pixels changed" << std::endl;
       ++iteration;
     }
-  }    
+  } 
   else if(postFilter_opt[0]=="promorph"){
     //Progressive morphological filter tgrs2003_zhang vol41 pp 872-882
     //first iteration is performed assuming only minima are selected using options -fir all -comp min
@@ -376,8 +376,8 @@ int main(int argc,char **argv) {
       try{
         nchange=theFilter.morphology(inputData,outputData,"erode",dim,dim,disc_opt[0],hThreshold);
         theFilter.morphology(outputData,inputData,"dilate",dim,dim,disc_opt[0],hThreshold);
-	theFilter.doit(inputData,outputData,"median",dim,dim,1,disc_opt[0]);
-	inputData=outputData;
+        theFilter.doit(inputData,outputData,"median",dim,dim,1,disc_opt[0]);
+        inputData=outputData;
       }
       catch(std::string errorString){
         cout << errorString << endl;
@@ -387,14 +387,14 @@ int main(int argc,char **argv) {
       hThreshold=hThreshold_opt[0]+maxSlope_opt[0]*(newdim-dim)*input.getDeltaX();
       dim=newdim;
       if(hThreshold_opt.size()>1){
-	if(hThreshold>hThreshold_opt[1]){
-	  hThreshold=hThreshold_opt[1];
-	}
+        if(hThreshold>hThreshold_opt[1]){
+          hThreshold=hThreshold_opt[1];
+        }
       }
       std::cout << "iteration " << iteration << ": " << nchange << " pixels changed" << std::endl;
       ++iteration;
     }
-  }    
+  }
   else if(postFilter_opt[0]=="open"){
     try{
       theFilter.morphology(inputData,tmpData,"erode",dim_opt[0],dim_opt[0],disc_opt[0],hThreshold_opt[0]);
@@ -416,8 +416,22 @@ int main(int argc,char **argv) {
       exit(1);
     }
   }
+  if(verbose_opt[0]){
+    std::cout << "writing data block" << std::endl;
+    std::cout << "outputData.nCols(): " << outputData.nCols() << std::endl;
+    std::cout << "outputData.nRows(): " << outputData.nRows() << std::endl;
+    std::cout << "outputWriter.nrOfCol(): " << outputWriter.nrOfCol() << std::endl;
+    std::cout << "outputWriter.nrOfRow(): " << outputWriter.nrOfRow() << std::endl;
+    std::cout << "outputWriter.getDataType(): " << outputWriter.getDataType() << std::endl;
+  }
   //write outputData to outputWriter
-  outputWriter.writeDataBlock(outputData,GDT_Float64,0,outputData.nCols()-1,0,outputData.nRows()-1);
+  try{
+    outputWriter.writeDataBlock(outputData,0,outputData.nCols()-1,0,outputData.nRows()-1);
+  }
+  catch(std::string errorString){
+    cout << errorString << endl;
+    exit(1);
+  }
 
   // progress=1;
   // pfnProgress(progress,pszMessage,pProgressArg);
